@@ -5,9 +5,9 @@ aiCI <- function(asr.model, Dimnames = NULL, alpha = 0.05)
    theta.vec <- summary(asr.model)$varcomp$component
    UCL <- theta.vec - za2*sqrt(hii.vec)
    LCL <- theta.vec + za2*sqrt(hii.vec)
-  CIframe <- cbind(UCL, theta.vec, LCL)
+  CIframe <- cbind(LCL, theta.vec, UCL)
   if(!is.null(Dimnames)) dimnames(CIframe)[[1]] <- Dimnames
-  dimnames(CIframe)[[2]] <- c("UCL", "estimate", "LCL")
+  dimnames(CIframe)[[2]] <- c("LCL", "estimate", "UCL")
 return(CIframe)
 }
 
