@@ -4,9 +4,9 @@
 #in the 'MCMCglmm' package
 ################################################
 
-numPed<-function(pedigree)
+numPed<-function(pedigree, check = TRUE)
 {
-      
+ if(check){      
   if(length(which(pedigree[, 2] == 0)) > 0){
     pedigree[which(pedigree[, 2] == 0), 2] <- NA
     warning("Zero in the dam column interpreted as a missing parent")
@@ -35,6 +35,7 @@ numPed<-function(pedigree)
   if (sum(duplicated(pedigree[, 1])) > 0) {
             stop("some individuals appear more than once in the pedigree")
         }
+ }
   numeric.pedigree <- matrix(as.integer(-998), dim(pedigree)[1], dim(pedigree)[2])
   numeric.pedigree[, 1] <- as.integer(seq(1, dim(pedigree)[1], 1))
   numeric.pedigree[, 2] <- match(pedigree[, 2], pedigree[, 1], nomatch = -998)
@@ -42,17 +43,17 @@ numPed<-function(pedigree)
   dnmiss <- which(numeric.pedigree[, 2] != -998)
   snmiss <- which(numeric.pedigree[, 3] != -998)
   bnmiss <- which(numeric.pedigree[, 2] != -998 & numeric.pedigree[, 3] != -998)
-
+ if(check){
   if (length(intersect(numeric.pedigree[, 2][dnmiss], numeric.pedigree[, 3][snmiss])) > 0 & (length(dnmiss) > 0) & (length(snmiss) > 0)) {
             warning("Dams appearing as Sires")
         }
   if (any(numeric.pedigree[, 2][dnmiss] > numeric.pedigree[, 1][dnmiss]) & (length(dnmiss) > 0)) {
-            stop("Dams appearing before their offspring: first use 'fixPedigree' from pedantics")
+            stop("Offspring appearing before their dams: first use 'fixPedigree' from pedantics")
         }
   if (any(numeric.pedigree[, 3][snmiss] > numeric.pedigree[, 1][snmiss]) & (length(snmiss) > 0)) {
-            stop("sires appearing before their offspring: first use 'fixPedigree' from pedantics")
+            stop("Offspring appearing before their Sires: first use 'fixPedigree' from pedantics")
         }
-
+ }
 numeric.pedigree
 }
 
